# Mobicoop V3 - User Service

Mobicoop V3 - User service. Manages user-related data.

## Installation

You need [Docker](https://docs.docker.com/engine/) and [Docker-compose](https://docs.docker.com/compose/).

Copy `.env.dist` to `.env` :

```bash
cp .env.dist .env
```

and modify it to suit your needs.

Then execute :

```bash
docker-compose up -d
```

The app runs automatically on the port defined in `SERVICE_PORT` of `.env` file (default : _3001_).

## Usage

The app exposes the following [gRPC](https://grpc.io/) services :

-   **FindByUuid** : find a user by its uuid

    ```json
    {
        "uuid": "80126a61-d128-4f96-afdb-92e33c75a3e1"
    }
    ```

-   **FindAll** : find all users; you can use pagination with `page` (default:_1_) and `perPage` (default:_10_)

    ```json
    {
        "page": 1,
        "perPage": 10
    }
    ```

-   **Create** : create a user (note that uuid is optional, a uuid will be automatically attributed if it is not provided)

    ```json
    {
        "email": "jezabel.doe@email.com",
        "firstName": "Jezabel",
        "lastName": "Doe"
    }
    ```

-   **Update** : update a user

    ```json
    {
        "firstName": "Jezabel-Katarina",
        "email": "jezabel-katarina.doe@email.com",
        "uuid": "30f49838-3f24-42bb-a489-8ffb480173ae"
    }
    ```

-   **Delete** : delete a user by its uuid

    ```json
    {
        "uuid": "80126a61-d128-4f96-afdb-92e33c75a3e1"
    }
    ```

## Test

```bash
# unit tests
docker exec v3_user sh -c "npm run test"

# test coverage
docker exec v3_user sh -c "npm run test:cov"
```

Note : you can run all npm commands directly _outside_ the container (see _scripts_ section of `package.json` for available commands), but you need NodeJS installed locally. We **strongly** advise to install [Node Version Manager](https://github.com/nvm-sh/nvm) !

## License

Mobicoop V3 - User Service is [AGPL licensed](LICENSE).
